@@ -1,4 +1,5 @@
-__version__ = '2.0'
+__version__ = "3.0.1"
+__all__ = ["while_true_print_howdyho_help"]
 
 
 def while_true_print_howdyho_help():
